Author: rhuijben
Date: Sun Apr  3 17:22:01 2011
New Revision: 1088342

URL: http://svn.apache.org/viewvc?rev=1088342&view=rev
Log:
Remove two more database operations for every file touched by an update
and/or checkout, by reading the mime type from the property hash which we
just used instead of from the database.

* subversion/libsvn_wc/update_editor.c
  (close_file): Don't read a property for notifation if we already have
    the value available.

Modified:
    subversion/trunk/subversion/libsvn_wc/update_editor.c

Modified: subversion/trunk/subversion/libsvn_wc/update_editor.c
URL: 
http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_wc/update_editor.c?rev=1088342&r1=1088341&r2=1088342&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_wc/update_editor.c (original)
+++ subversion/trunk/subversion/libsvn_wc/update_editor.c Sun Apr  3 17:22:01 
2011
@@ -4383,10 +4383,12 @@ close_file(void *file_baton,
       notify->revision = *eb->target_revision;
       notify->old_revision = fb->old_revision;
 
-      /* Fetch the mimetype */
-      SVN_ERR(svn_wc__internal_propget(&mime_type, eb->db, fb->local_abspath,
-                                       SVN_PROP_MIME_TYPE,
-                                       scratch_pool, scratch_pool));
+      /* Fetch the mimetype from the actual properties */
+      mime_type = (new_actual_props != NULL)
+                        ? apr_hash_get(new_actual_props, SVN_PROP_MIME_TYPE,
+                                       APR_HASH_KEY_STRING)
+                        : NULL;
+
       notify->mime_type = mime_type == NULL ? NULL : mime_type->data;
 
       eb->notify_func(eb->notify_baton, notify, scratch_pool);


Reply via email to